<?php declare(strict_types=1);

namespace EuKit\Base\Services;

use EuKit\Base\AssetsHelper;
use EuKit\Base\Interfaces\ThemeServiceStartup;

/**
 * Class ScriptsServiceStartup
 * @package EuKit\Base\Services
 */
class ScriptsServiceStartup implements ThemeServiceStartup
{

    /**
     * @var string
     */
    private $prefix;

    private $scriptVersion;

    public function __construct(string $prefix, $scriptVersion = false)
    {
        $this->prefix = $prefix;
        $this->scriptVersion = $scriptVersion;
    }

    public function setup(): void
    {
        add_action('admin_enqueue_scripts', [&$this, 'enqueueAdminScripts']);
        add_action('wp_enqueue_scripts', [&$this, 'enqueueBaseThemeScripts']);
        add_action('wp_enqueue_scripts', [&$this, 'enqueueScripts']);
    }

    public function enqueueScripts(): void
    {
        // Remove jquery
        wp_deregister_script('jquery');

        // Remove the bootstrap version added by Everyboard
        wp_deregister_style('bootstrap-css');
        wp_deregister_script('bootstrap-js');
        wp_deregister_style('wp-core-ui');

        $this->addStyle("{$this->prefix}-style", AssetsHelper::getStyleUrl('style'), [], $this->scriptVersion);
        $this->addScript("{$this->prefix}-head-js", AssetsHelper::getScriptUrl('head'), [], $this->scriptVersion);
        $this->addScript("{$this->prefix}-body-js", AssetsHelper::getScriptUrl('body'), [], $this->scriptVersion,
            true);

        if (is_single()) {
            $this->addScript("{$this->prefix}-article-js", AssetsHelper::getScriptUrl('article'),
                ["{$this->prefix}-body-js"],
                $this->scriptVersion, true);
        }


        wp_localize_script("{$this->prefix}-body-js", 'infomaker', [
            'ajaxurl' => site_url('/ajax.php'),
        ]);
    }

    public function enqueueAdminScripts(): void
    {
        $this->addStyle("{$this->prefix}-admin-style", AssetsHelper::getStyleUrl('admin'), [], $this->scriptVersion);
        $this->addScript("{$this->prefix}-admin-js", AssetsHelper::getScriptUrl('admin'), ['jquery'],
            $this->scriptVersion,
            true);
    }

    public function enqueueBaseThemeScripts(): void
    {
        $this->addStyle('base-style', AssetsHelper::getBaseStyleUrl('style'), [], $this->scriptVersion);
        $this->addScript('base-head-js', AssetsHelper::getBaseScriptUrl('head'), [], $this->scriptVersion);
        $this->addScript('base-body-js', AssetsHelper::getBaseScriptUrl('body'), [], $this->scriptVersion, true);

        if (is_single()) {
            $this->addScript('base-article-js', AssetsHelper::getBaseScriptUrl('article'), ['base-body-js'],
                $this->scriptVersion, true);
        }
    }

    private function addScript($handle, $src = '', $deps = [], $ver = false, $inFooter = false)
    {
        if ( ! empty($src)) {
            wp_enqueue_script($handle, $src, $deps, $ver, $inFooter);
        }
    }

    private function addStyle($handle, $src = '', $deps = [], $ver = false, $media = 'all')
    {
        if ( ! empty($src)) {
            wp_enqueue_style($handle, $src, $deps, $ver, $media);
        }
    }
}
